@@ -18,7 +18,7 @@ Xphi <- D$Xphi
 Xdet <- D$Xdet
 y <- D$y  # MxJT 
 
-Xlam.offset <- D$X.offset
+Xlam.offset <- D$Xlam.offset
 Xphi.offset <- D$Xphi.offset
 Xdet.offset <- D$Xdet.offset
 if(is.null(Xlam.offset)) Xlam.offset <- rep(0, nrow(Xlam))
@@ -30,10 +30,10 @@ k <- 0:K
 lk <- length(k)
 M <- nrow(y)  
 T <- data@numPrimary
-R <- ncol(y)
-J <- R / T
+R <- numY(data) / T
+J <- obsNum(data) / T
 
-y <- array(y, c(M, J, T))
+y <- array(y, c(M, R, T))
 y <- aperm(y, c(1,3,2))
 yt <- apply(y, 1:2, function(x) {
     if(all(is.na(x))) 
@@ -51,15 +51,15 @@ nLP <- ncol(Xlam)
 nPP <- ncol(Xphi)
 nDP <- ncol(Xdet)
 nP <- nLP + nPP + nDP + ifelse(mixture=='NB', 1, 0)
+if(!missing(starts) && length(starts) != nP)
+    stop(paste("The number of starting values should be", nP))
 
-cp <- array(as.numeric(NA), c(M, T, J+1))
-g <- matrix(as.numeric(NA), M, lk)
 
 lfac.k <- lgamma(k+1)
 kmyt <- array(NA, c(M, T, lk))
 lfac.kmyt <- array(0, c(M, T, lk))
 fin <- matrix(NA, M, lk)
-naflag <- array(NA, c(M, T, J))
+naflag <- array(NA, c(M, T, R))
 for(i in 1:M) {
     fin[i, ] <- k - max(yt[i,], na.rm=TRUE) >= 0
     for(t in 1:T) {
@@ -71,10 +71,6 @@ for(i in 1:M) {
         }
     }
     
-## NA handling
-# Sites w/ missing siteCovs should be removed beforehand
-# Sites w/ some missing yearlySiteCovs shoul be retained but      
-
 nll <- function(pars) {
     lambda <- exp(Xlam %*% pars[1:nLP] + Xlam.offset) 
     phi <- drop(plogis(Xphi %*% pars[(nLP+1):(nLP+nPP)] + Xphi.offset))
@@ -86,26 +82,25 @@ nll <- function(pars) {
     p <- matrix(p, nrow=M, byrow=TRUE)
     p <- array(p, c(M, J, T))
     p <- aperm(p, c(1,3,2))     
-    cp <- array(as.numeric(NA), c(M, T, J+1))
+    cp <- array(as.numeric(NA), c(M, T, R+1))
     
-    for(t in 1:T) cp[,t,1:J] <- do.call(piFun, list(p[,t,]))
-    cp[,,1:J] <- cp[,,1:J] * phi
-    cp[,,J+1] <- 1 - apply(cp[,,1:J], 1:2, sum, na.rm=TRUE) # is na.rm=T valid?
+    for(t in 1:T) cp[,t,1:R] <- do.call(piFun, list(p[,t,]))
+    cp[,,1:R] <- cp[,,1:R] * phi
+    cp[,,R+1] <- 1 - apply(cp[,,1:R], 1:2, sum, na.rm=TRUE) # Double-check
     
     switch(mixture, 
         P = f <- sapply(k, function(x) dpois(x, lambda)),
         NB = f <- sapply(k, function(x) dnbinom(x, mu=lambda, 
             size=exp(pars[nP]))))
+    g <- matrix(as.numeric(NA), M, lk)
     for(i in 1:M) {
         A <- matrix(0, lk, T)
         for(t in 1:T) {
-            if(all(naflag[i,t,])) 
-                A[,t] <- 0 
-            else                 
+            na <- naflag[i,t,]
+            if(!all(na))            
                 A[, t] <- lfac.k - lfac.kmyt[i, t,] + 
-                    sum(y[i, t, !naflag[i,t,]] * 
-                    log(cp[i, t, which(!naflag[i,t,])])) + 
-                    kmyt[i, t,] * log(cp[i, t, J+1])
+                    sum(y[i, t, !na] * log(cp[i, t, which(!na)])) + 
+                    kmyt[i, t,] * log(cp[i, t, R+1])
             }
         g[i,] <- exp(rowSums(A))
         }
